@@ -430,8 +430,6 @@ if_copyrt(struct dhcpcd_ctx *ctx, struct rt *rt, struct nlmsghdr *nlm)
 	memset(rt, 0, sizeof(*rt));
 	if (rtm->rtm_type == RTN_UNREACHABLE)
 		rt->rt_flags |= RTF_REJECT;
-	if (rtm->rtm_scope == RT_SCOPE_HOST)
-		rt->rt_flags |= RTF_HOST;
 
 	rta = (struct rtattr *)RTM_RTA(rtm);
 	len = RTM_PAYLOAD(nlm);
@@ -491,6 +489,8 @@ if_copyrt(struct dhcpcd_ctx *ctx, struct rt *rt, struct nlmsghdr *nlm)
 
 	rt->rt_netmask.sa_family = rtm->rtm_family;
 	sa_fromprefix(&rt->rt_netmask, rtm->rtm_dst_len);
+	if (sa_is_allones(&rt->rt_netmask))
+		rt->rt_flags |= RTF_HOST;
 
 	#if 0
 	if (rt->rtp_ifp == NULL && rt->src.s_addr != INADDR_ANY) {
@@ -1228,7 +1228,7 @@ if_route(unsigned char cmd, const struct rt *rt)
 			nlm.rt.rtm_protocol = RTPROT_BOOT;
 		if (rt->rt_ifp->flags & IFF_LOOPBACK)
 			nlm.rt.rtm_scope = RT_SCOPE_HOST;
-		else if (gateway_unspec || sa_is_allones(&rt->rt_netmask))
+		else if (gateway_unspec)
 			nlm.rt.rtm_scope = RT_SCOPE_LINK;
 		else
 			nlm.rt.rtm_scope = RT_SCOPE_UNIVERSE;
